@@ -1,4 +1,6 @@
 from . import models
 from . import controllers
 from . import services
-from . import wizards
\ No newline at end of file
+from . import wizards
+from . import tests
+from .hooks import post_init_hook
\ No newline at end of file
